<?php

/**
 * Provides a set of static methods to use within the theme so we can have extra
 * methods similar to body_class()
 *
 * @since 1.0.0
 *
 */

class WP_CLF_Lite_Content_Classes {

	/**
	 * Display classes for the root page content area
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return null
	 */

	public static function root_page_class( $class = '' ) {

		// Separates classes with a single space, collates classes
		echo 'class="' . join( ' ', static::get_root_page_class( $class ) ) . '"';

	}/* primary_content_class() */

	/**
	 * Provide an array of content classes that will be applied to the root page area
	 * i.e. div#page
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return array Array of classes.
	 */

	public static function get_root_page_class( $class = '' ) {

		$classes = array();

		// added by _s
		$classes[] = 'hfeed';
		$classes[] = 'site';

		return static::get_generic_class( $class, $classes, 'root_page' );

	}/* get_primary_content_class() */


	/**
	 * Display classes for the root content area
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return null
	 */

	public static function root_content_class( $class = '' ) {

		// Separates classes with a single space, collates classes
		echo 'class="' . join( ' ', static::get_root_content_class( $class ) ) . '"';

	}/* primary_content_class() */

	/**
	 * Provide an array of content classes that will be applied to the root page area
	 * i.e. div#content
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return array Array of classes.
	 */

	public static function get_root_content_class( $class = '' ) {

		$classes = array();

		// added by _s
		$classes[] = 'site-content';

		return static::get_generic_class( $class, $classes, 'root_content' );

	}/* get_primary_content_class() */


	/**
	 * Display classes for the primary content area
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return null
	 */

	public static function primary_content_class( $class = '' ) {

		// Separates classes with a single space, collates classes
		echo 'class="' . join( ' ', static::get_primary_content_class( $class ) ) . '"';

	}/* primary_content_class() */

	/**
	 * Provide an array of content classes that will be applied to the primary content area
	 * i.e. div#primary
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return array Array of classes.
	 */

	public static function get_primary_content_class( $class = '' ) {

		$classes = array();

		// This one is added by _s
		$classes[] = 'content-area';

		return static::get_generic_class( $class, $classes, 'primary_content' );

	}/* get_primary_content_class() */


	/**
	 *  Display classes for the <main> tag
	 *  i.e. <main id="main">
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return null
	 */

	public static function main_content_class( $class = '' ) {

		// Separates classes with a single space, collates classes
		echo 'class="' . join( ' ', static::get_main_content_class( $class ) ) . '"';

	}/* main_content_class() */


	/**
	 * Provide an array of content classes that will be applied to the <main> tag
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return array Array of classes.
	 */

	public static function get_main_content_class( $class = '' ) {

		$classes = array();

		// Added by _s
		$classes[] = 'site-main';

		return static::get_generic_class( $class, $classes, 'main' );

	}/* get_main_content_class() */


	/**
	 *  Display classes for the container which contains widebar widgets
	 *  i.e. <div id="secondary">
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return null
	 */

	public static function secondary_content_class( $class = '' ) {

		// Separates classes with a single space, collates classes
		echo 'class="' . join( ' ', static::get_secondary_content_class( $class ) ) . '"';

	}/* main_content_class() */


	/**
	 * Provide an array of classes that will be applied to the <div id="secondary">
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $class One or more classes to add to the class list.
	 * @return array Array of classes.
	 */

	public static function get_secondary_content_class( $class = '' ) {

		$classes = array();

		// Added by _s
		$classes[] = 'widget-area';

		return static::get_generic_class( $class, $classes, 'widget_area' );

	}/* get_main_content_class() */


	/**
	 * A generic method to allow us to have classes output in different areas without needing
	 * a separate getter for each
	 *
	 * @since 1.0.0
	 *
	 * @param   -
	 * @return
	 */

	private static function get_generic_class( $class = '', $classes = array(), $section = false ) {

		if ( ! $section ) {
			return new WP_Error( '1', __( '$section is required in WP_CLF_Lite_Content_Classes::get_generic_class()' ) );
		}

		$section = sanitize_title_with_dashes( $section );

		if ( ! empty( $class ) ) {

			if ( ! is_array( $class ) ) {
				$class = preg_split( '#\s+#', $class );
			}

			$classes = array_merge( $classes, $class );
		} else {

			// Ensure that we always coerce class to being an array.
			$class = array();
		}

		$classes = array_map( 'esc_attr', $classes );

		/**
		 * Filters the list of content classes
		 *
		 * @since 1.0.0
		 *
		 * @param array  $classes An array of classes.
		 * @param string $class   A comma-separated list of additional classes
		 */
		$classes = apply_filters( 'wp_clf_lite_' . $section . '_classes', $classes, $class );

		return array_unique( $classes );

	}/* get_generic_class() */

}/* class WP_CLF_Lite_Custom_Functions */
